@@ -58,6 +58,17 @@
   :group 'emh
   :type 'boolean)
 
+(defcustom emh-icon-directory (if (fboundp 'locate-data-directory)
+				  (locate-data-directory "emh")
+				(let ((icons (expand-file-name 
+					      "emh/icons/"
+					      data-directory)))
+				  (if (file-directory-p icons)
+				      icons)))
+  "*Directory to load the icon files from, or nil if none."
+  :group 'emh
+  :type '(choice (const :tag "none" nil)
+                 string))
 
 ;;; @ functions
 ;;;
@@ -344,6 +355,12 @@ digest are inserted into the folder after that message."
 
 (eval-after-load "bbdb" '(require 'mime-bbdb))
 
+;;; @ Toolbar
+
+(if (and (not (featurep 'xemacs))
+	 (boundp 'emacs-major-version)
+	 (>= emacs-major-version 21))
+    (require 'emh-e21))
 
 ;;; @ end
 ;;;
